# frozen_string_literal: true

#
# Cookbook:: snu_nginx
# Library:: helpers/config
#
# Copyright:: 2019, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

module SnuNginxCookbook
  module Helpers
    # Some helper methods to mix into the snu_nginx_config resource.
    module Config
      # Ensure the various Nginx config dirs exist.
      def create_config_dirs!
        config_dirs.each do |d|
          directory d do
            owner 'root'
            group 'root'
            mode '0755'
            recursive true
          end
        end
      end

      # List the full paths to the various config sub-directories under /etc/nginx.
      def config_dirs
        %w[conf.d modules-available modules-enabled sites-available sites-enabled snippets].map do |d|
          ::File.join(new_resource.dir, new_resource.service_name, d)
        end
      end

      # Ensure the Nginx logs have the right ownership.
      def fix_log_permissions!(log_dir, user)
        directory log_dir do
          owner user
          group 'adm'
        end

        %w[access error].each do |f|
          file ::File.join(log_dir, "#{f}.log") do
            owner user
            group 'adm'
          end
        end
      end
    end
  end
end
