# frozen_string_literal: true

#
# Cookbook:: snu_nginx
# Library:: resource/snu_nginx_app
#
# Copyright:: 2019, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'chef/resource'

class Chef
  class Resource
    # A custom resource for managing Nginx packages.
    class SnuNginxApp < Resource
      provides(:snu_nginx_app) { false }

      default_action :install

      property :name, String, default: 'nginx'
      property :package_name, String, name_property: true
      property :version, String

      # The :install and :upgrade actions are nearly the same thing:
      #   - Pass the action on to an underlying package resource
      #
      # TODO: Should the :upgrade action trigger a restart? What if the user is
      #       only interested in the app resource and hasn't declared a service?
      %i[install upgrade].each do |act|
        action act do
          package new_resource.package_name do
            version new_resource.version unless new_resource.version.nil?
            action act
          end

          file "Delete Nginx's included default site" do
            path '/etc/nginx/conf.d/default.conf'
            action :nothing
            subscribes :delete, "package[#{new_resource.package_name}]", :immediately
          end
        end
      end

      # Remove the package.
      action :remove do
        package(new_resource.package_name) { action :remove }
      end
    end
  end
end
