# frozen_string_literal: true

#
# Cookbook:: snu_nginx
# Library:: resource/snu_nginx_app_debian
#
# Copyright:: 2019, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require_relative 'snu_nginx_app'

class Chef
  class Resource
    # A custom resource for managing Nginx packages on Debian platforms.
    class SnuNginxAppDebian < SnuNginxApp
      provides :snu_nginx_app, platform_family: 'debian'

      # Before installing or upgrading Nginx:
      #   - Freshen the APT cache
      #   - Ensure apt-transport-https and gnupg are installed
      #   - Ensure ca-certificates is installed and trusted
      #   - Configure the Nginx APT repo
      %i[install upgrade].each do |act|
        action act do
          apt_update

          package %w[gnupg apt-transport-https]

          package 'ca-certificates'

          execute 'update-ca-certificates --fresh' do
            action :nothing
            subscribes :run, 'package[ca-certificates]', :immediately
          end

          apt_repository 'nginx' do
            uri "https://nginx.org/packages/#{node['platform']}"
            distribution node['lsb']['codename']
            components %w[nginx]
            key 'https://nginx.org/keys/nginx_signing.key'
          end

          super()
        end
      end

      # For the :remove action:
      #   - Do an APT purge instead of remove
      #   - Remove the APT repository
      action :remove do
        super()
        edit_resource!(:package, new_resource.package_name) { action :purge }
        apt_repository('nginx') { action :remove }
      end
    end
  end
end
