# frozen_string_literal: true

#
# Cookbook:: snu_nginx
# Library:: resource/snu_nginx_config_base
#
# Copyright:: 2019, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'chef/resource'

class Chef
  class Resource
    # A base class for our various config-y resources to inherit from. Not
    # meant to be used on its own.
    class SnuNginxConfigBase < Resource
      provides(:snu_nginx_config_base) { false }

      default_action :create

      # The name of this config's service will be used to construct its path.
      property :service_name, String, default: 'nginx'

      # The system's main config dir to be used in assembling a
      # "#{dir}/#{service_name}/nginx.conf" path.
      property :dir, String, default: '/etc'

      # The name, cookbook, and variables to use as an nginx.conf template.
      property :template, String, required: true
      property :cookbook, String, required: true
      property :variables, Hash, default: {}

      # Use method_missing to support merging individual "properties" into the
      # variables property instead of overriding the entire thing..
      #
      # (see Chef::Resource#method_missing)
      def method_missing(method_symbol, *args, &block)
        super
      rescue NoMethodError
        raise if !block.nil? || args.length != 1

        new_vars = variables.merge(method_symbol => args[0])
        variables(new_vars)
      end

      #
      # We don't need anything special out of respond_to_missing? since all the
      # missing methods we allow get saved into the variables hash.
      #
      # (see Object#respond_to_missing)
      def respond_to_missing?(method_symbol, include_private = false)
        super
      end
    end
  end
end
